UsersRepositoryState class

Annotations

Constructors

UsersRepositoryState({List<UserVO> users = const [], bool isLastPage = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLastPage → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
users → List<UserVO>
final

Methods

copyWith({List<UserVO>? users, bool? isLastPage}) → UsersRepositoryState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited